//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QPAGESETUPDIALOG_C_H
#define QPAGESETUPDIALOG_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QPageSetupDialogH QPageSetupDialog_create(QPrinterH printer, QWidgetH parent);
C_EXPORT void QPageSetupDialog_destroy(QPageSetupDialogH handle);
C_EXPORT QPageSetupDialogH QPageSetupDialog_create2(QWidgetH parent);
C_EXPORT void QPageSetupDialog_addEnabledOption(QPageSetupDialogH handle, QPageSetupDialog::PageSetupDialogOption option);
C_EXPORT void QPageSetupDialog_setEnabledOptions(QPageSetupDialogH handle, unsigned int options);
C_EXPORT unsigned int QPageSetupDialog_enabledOptions(QPageSetupDialogH handle);
C_EXPORT bool QPageSetupDialog_isOptionEnabled(QPageSetupDialogH handle, QPageSetupDialog::PageSetupDialogOption option);
C_EXPORT void QPageSetupDialog_setOption(QPageSetupDialogH handle, QPageSetupDialog::PageSetupDialogOption option, bool on);
C_EXPORT bool QPageSetupDialog_testOption(QPageSetupDialogH handle, QPageSetupDialog::PageSetupDialogOption option);
C_EXPORT void QPageSetupDialog_setOptions(QPageSetupDialogH handle, unsigned int options);
C_EXPORT unsigned int QPageSetupDialog_options(QPageSetupDialogH handle);
C_EXPORT int QPageSetupDialog_exec(QPageSetupDialogH handle);
C_EXPORT void QPageSetupDialog_open(QPageSetupDialogH handle, QObjectH receiver, const char* member);
#if defined DARWIN
C_EXPORT void QPageSetupDialog_setVisible(QPageSetupDialogH handle, bool visible);
#endif

#endif
