//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QITEMEDITORFACTORY_C_H
#define QITEMEDITORFACTORY_C_H

#include <QtGui>
#include "pascalbind.h"

C_EXPORT QWidgetH QItemEditorCreatorBase_createWidget(QItemEditorCreatorBaseH handle, QWidgetH parent);
C_EXPORT void QItemEditorCreatorBase_valuePropertyName(QItemEditorCreatorBaseH handle, QByteArrayH retval);
C_EXPORT QItemEditorFactoryH QItemEditorFactory_create();
C_EXPORT void QItemEditorFactory_destroy(QItemEditorFactoryH handle);
C_EXPORT QWidgetH QItemEditorFactory_createEditor(QItemEditorFactoryH handle, QVariant::Type type, QWidgetH parent);
C_EXPORT void QItemEditorFactory_valuePropertyName(QItemEditorFactoryH handle, QByteArrayH retval, QVariant::Type type);
C_EXPORT void QItemEditorFactory_registerEditor(QItemEditorFactoryH handle, QVariant::Type type, QItemEditorCreatorBaseH creator);
C_EXPORT const QItemEditorFactoryH QItemEditorFactory_defaultFactory();
C_EXPORT void QItemEditorFactory_setDefaultFactory(QItemEditorFactoryH factory);

#endif
