//******************************************************************************
//  Copyright (c) 2005-2011 by Jan Van hijfte
//
//  See the included file COPYING.TXT for details about the copyright.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//******************************************************************************


#ifndef QLCLNETWORKCOOKIE_C_H
#define QLCLNETWORKCOOKIE_C_H

#include "qlclnetworkcookie.h"
#include "pascalbind.h"

C_EXPORT QLCLNetworkCookieJarH QLCLNetworkCookieJar_create(QObjectH parent);
C_EXPORT void QLCLNetworkCookieJar_destroy(QLCLNetworkCookieJarH handle);
C_EXPORT void QLCLNetworkCookieJar_setRawCookies(QLCLNetworkCookieJarH handle, const char* rawCookies);
C_EXPORT void QLCLNetworkCookieJar_getRawCookies(QLCLNetworkCookieJarH handle, QByteArrayH rawCookies);

#endif
